@@ -14,7 +14,7 @@ use File::Copy qw(copy);
 use File::Path qw(mkpath rmtree);
 use B qw(perlstring);
 
-our $VERSION = '0.009017'; # 0.009.017
+our $VERSION = '0.009018'; # 0.009.017
 
 $VERSION = eval $VERSION;
 
@@ -147,13 +147,14 @@ sub packlists_containing {
   }
   my @search = grep -d $_, map catdir($_, 'auto'), @INC;
   my %pack_rev;
-  my $cwd = cwd;
-  find(sub {
-    return unless $_ eq '.packlist' && -f $_;
-    $pack_rev{$_} = $File::Find::name for lines_of $File::Find::name;
+  find({
+    no_chdir => 1,
+    wanted => sub {
+      return unless /[\\\/]\.packlist$/ && -f $_;
+      $pack_rev{$_} = $File::Find::name for lines_of $File::Find::name;
+    },
   }, @search);
-  chdir($cwd) or die "Couldn't chdir back to ${cwd} after find: $!";
-  my %found; @found{map +($pack_rev{$INC{$_}}||()), @targets} = ();
+  my %found; @found{map +($pack_rev{Cwd::abs_path($INC{$_})}||()), @targets} = ();
   sort keys %found;
 }
 
